@@ -2,15 +2,15 @@
 from pony.orm import *
 from tkinter import messagebox
 import tkinter as tk
-from tkinter import ttk
 from tkinter import *
+from tkinter import ttk
 from fui.main_ui import MainUI
 from langcodes import Language
 import gettext
-import sys,os
-from fmodel import funing_m as fm
+import sys
+import os
 from fmodel.funing_m import Person, PersonInfo
-import  tkinter.filedialog as tkf
+import tkinter.filedialog as tkf
 import cv2
 from PIL import Image , ImageTk
 import dlib
@@ -45,7 +45,8 @@ class _MainUI():
         self.resize_rate = 0.25;    self.lang_code = lang_code
         self.fxfy = None;           self.ins_vars = {}
 
-        self.known_encodings = pickle.load( open(face_encodings_path , 'rb') )
+        self.known_encodings = dict(\
+            pickle.load( open(face_encodings_path , 'rb') ))
         self.comparison_tolerance = comparison_tolerance
             
         try:self.screenwidth = self.mainui.root.winfo_screenwidth();\
@@ -301,7 +302,7 @@ class _MainUI():
         if self.pause:
             if self.curr_face_id is None: return
 
-            p = select(p for p in fm.Person \
+            p = select(p for p in Person \
                 if p.id == self.curr_face_id ).first()
             if p is None: return
 
@@ -311,6 +312,7 @@ class _MainUI():
             self.mainui.entryframe.uuid_entry.insert(0 , p.id)
             self.mainui.entryframe.uuid_entry['state'] = 'disabled'
             self.mainui.entryframe.name_entry.insert(0 , p.name)
+            self.mainui.entryframe.gender_entry.insert(0 , p.gender)
             self.mainui.entryframe.DOB_entry.insert(0 , p.dob )
             self.mainui.entryframe.address_entry.insert(0 , p.address)
             self.mainui.entryframe.note_text.insert(END , p.note)
@@ -386,16 +388,19 @@ class _MainUI():
         if person_exists:
             if debug:
                 print( 'Person exists')
-            p = select(p for p in fm.Person if \
+            p = select(p for p in Person if \
                 p.id == self.curr_face_id ).first()
             p.dob = self.mainui.entryframe.DOB_entry.get()
             p.name = self.mainui.entryframe.name_entry.get()
+            p.gender = self.mainui.entryframe.gender_entry.get()
             p.note = self.mainui.entryframe.note_text.get(1.0, 'end')
 
         else:
-            print('New person')
+            if debug:
+                print('New person')
             p = Person( id = str(uuid.uuid4()),\
-                name = self.mainui.entryframe.name_entry.get() ,\
+                name = self.mainui.entryframe.name_entry.get() ,
+                gender = self.mainui.entryframe.gender_entry.get(),
                 dob = self.mainui.entryframe.DOB_entry.get(), 
                 address = self.mainui.entryframe.address_entry.get(),
                 note = self.mainui.entryframe.note_text.get(1.0, 'end') )
@@ -414,8 +419,8 @@ class _MainUI():
             if len(label_value+  value_v+ note_value )< 1: continue
             
             if PersonInfo.exists(person_id =p.id, label =label_value):
-                p_i = select( p for p in PersonInfo \
-                    if p.person_id == p.id and p.label == label_value)\
+                p_i = select( _p_i for _p_i in PersonInfo \
+                    if _p_i.person_id == p.id and _p_i.label == label_value)\
                     .first()
 
                 if debug: print( 'PersonInfo exists' )
@@ -427,11 +432,14 @@ class _MainUI():
                     label = label_value,    value = value_v
                 )
 
-        if len(self.known_encodings) > 0:
-            self.known_encodings[ p.id] = self.known_encodings[ p.id ] +\
-                [ self.curr_f_encoding ]
+        if len( self.known_encodings) < 1 \
+            or self.known_encodings.get(p.id) is None:
+                self.known_encodings.setdefault(p.id ,\
+                    [self.curr_f_encoding])
         else:
-            self.known_encodings[ p.id] = [ self.curr_f_encoding ]
+            self.known_encodings.setdefault( p.id ,\
+                [self.known_encodings.get(p.id)]+\
+                [self.curr_f_encoding])
 
         pickle.dump( self.known_encodings, open(face_encodings_path, 'wb'))
         
@@ -496,9 +504,7 @@ class _MainUI():
         for i in self.ins_vars.keys():
             self.mainui.addinfoframe.frame.nametowidget(i).pack_forget()
         self.ins_vars = {}
-        
-
-     
+             
 ###############################################################################
 # ADD_INFO_FRAME FUNCTIONS  END
 
@@ -520,13 +526,8 @@ class _MainUI():
         if restartapp:
             setting_yml['lang_code'] = new_lang_code
             yaml.dump( setting_yml, open( setting_path, 'w') )
-
-            if self.iru is not None:
-                self.release()
-
             sys_executable = sys.executable
             os.execl(sys_executable, sys_executable, * sys.argv)
-
         pass
 
 ###############################################################################
@@ -549,7 +550,6 @@ class _MainUI():
 ###############################################################################
 # OTHER FUNCTIONS END
 
-
 class IRU():
     def __init__(self, video_source = 0 ):
         self.video_source = video_source
