@@ -8,17 +8,17 @@ from datetime import date
 
 from setting import base_dir, data_file_path
 from pony.orm.dbapiprovider import OperationalError
+from _fui.error import db_no_col
 
 db = Database()
 
-
-
 # https://docs.ponyorm.org/firststeps.html#database-binding
 db.bind(provider='sqlite', filename = data_file_path )
 
 class Person( db.Entity ):
     id = PrimaryKey( str )
     name = Optional( str )
+    gender = Optional( str )
     dob = Optional( str )
     address = Optional( str )
     note = Optional( str )
@@ -35,4 +35,4 @@ try:
     db.generate_mapping( create_tables = True )
 except OperationalError as e:
     print( e )
-    print('\nAdd specific column to database (^_^)\n' )
\ No newline at end of file
+    db_no_col( data_file_path )
\ No newline at end of file
